apispec SerpycoPlugin
---------------------

`SerpycoPlugin` is [Serpyco](https://gitlab.com/sgrignard/serpyco) apispec integration plugin.
Code of this repository strongly inspired and based on apispec source code [here](https://github.com/marshmallow-code/apispec/tree/b4bf604b6847b87616b84aed417154a58a97a8de)

Install
-------

    pip install apispec_serpyco

Tests
-----

To execute tests, be sure to install test tools

    pip install -e ".[test]"

To execute tests, run

    pytest tests
